loadModel abstract method

Future<ExecuTorchModel> loadModel(
  1. String filePath
)

Load an ExecuTorch model from a file path

filePath must point to a valid ExecuTorch .pte model file. Returns the loaded model instance that can be used for inference.

The model will be cached and accessed later via getLoadedModel.

Implementation

Future<ExecuTorchModel> loadModel(String filePath);