PostprocessingException class

Exception thrown during postprocessing operations.

Thrown when model output tensors cannot be converted to results.

Inheritance

Constructors

PostprocessingException(String message, [Object? cause])
Creates a postprocessing exception with the given message.
const

Properties

cause Object?
The underlying cause of this exception, if any.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
The error message describing what went wrong.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited